'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const qwik = require('@builder.io/qwik');

const DEFAULT_RESOLUTIONS = [
  3840,
  1920,
  1280,
  960,
  640
];
const ImageContext = qwik.createContextId("ImageContext");
const useImageProvider = (state) => {
  qwik.useContextProvider(ImageContext, state);
};
const isValid = (value) => value || value === 0;
const getStyles = ({ placeholder, width, height, aspectRatio, objectFit = "cover", layout }) => {
  const isRatioValid = isValid(aspectRatio);
  if (height === "auto" && width === "auto" && isRatioValid)
    console.warn(`To use the aspect ratio either set the width or the height`);
  if (height !== "auto" && layout !== "fixed" && isRatioValid)
    console.warn(`To maintain the aspect ratio we set 'height: "auto"'`);
  const baseStyles = {
    "object-fit": objectFit,
    background: placeholder || "transparent"
  };
  switch (layout) {
    case "fixed":
      return {
        ...baseStyles,
        width: isValid(width) ? `${width}px` : void 0,
        height: isValid(height) ? `${height}px` : void 0
      };
    case "constrained":
      return {
        ...baseStyles,
        width: "100%",
        height: isRatioValid ? "auto" : void 0,
        "max-width": isValid(width) ? `${width}px` : void 0,
        "max-height": isValid(height) ? `${height}px` : void 0,
        "aspect-ratio": isRatioValid ? `${aspectRatio}` : void 0
      };
    case "fullWidth": {
      const heightStyle = {
        height: isRatioValid ? "auto" : isValid(height) ? `${height}px` : void 0
      };
      return {
        ...baseStyles,
        ...heightStyle,
        width: "100%",
        "aspect-ratio": isRatioValid ? `${aspectRatio}` : void 0
      };
    }
  }
};
const getSizes = ({ width, layout }) => {
  if (!width || !layout)
    return void 0;
  switch (layout) {
    case `constrained`:
      return `(min-width: ${width}px) ${width}px, 100vw`;
    case `fixed`:
      return `${width}px`;
    case `fullWidth`:
      return `100vw`;
    default:
      return void 0;
  }
};
const getSrcSet = async ({ src = "", width, height, aspectRatio, layout, resolutions, imageTransformer$ }) => {
  const breakpoints = getBreakpoints({
    width: typeof width === "string" ? parseInt(width, 10) : width,
    layout,
    resolutions: resolutions || DEFAULT_RESOLUTIONS
  });
  const srcSets = [];
  for await (const breakpoint of breakpoints.sort()) {
    let transformedHeight = typeof height === "string" ? parseInt(height, 10) : height;
    if (height && aspectRatio)
      transformedHeight = Math.round(breakpoint * aspectRatio);
    if (!imageTransformer$) {
      srcSets.push(`${src} ${breakpoint}w`);
      continue;
    }
    const transformed = await imageTransformer$({
      src,
      width: breakpoint,
      height: transformedHeight
    });
    srcSets.push(`${transformed} ${breakpoint}w`);
  }
  return srcSets.join(",\n");
};
const getBreakpoints = ({ width: widthAttribute, layout, resolutions = [] }) => {
  if (layout === "fullWidth")
    return resolutions;
  if (!widthAttribute)
    return [];
  const width = typeof widthAttribute === "string" ? parseInt(widthAttribute, 10) : widthAttribute;
  const doubleWidth = width * 2;
  if (layout === "fixed")
    return [
      width,
      doubleWidth
    ];
  if (layout === "constrained")
    return [
      width,
      doubleWidth,
      ...resolutions.filter((w) => w < doubleWidth)
    ];
  return [];
};
const Image = /* @__PURE__ */ qwik.componentQrl(/* @__PURE__ */ qwik.inlinedQrl((props) => {
  const state = qwik.useContext(ImageContext);
  const { resolutions, imageTransformer$, ...imageAttributes } = {
    ...state,
    ...props
  };
  const style = {
    ...props.style,
    ...getStyles(props)
  };
  const sizes = getSizes(props);
  const srcSetSignal = qwik.useSignal("");
  qwik.useTaskQrl(/* @__PURE__ */ qwik.inlinedQrl(async () => {
    const [imageTransformer$2, props2, resolutions2, srcSetSignal2] = qwik.useLexicalScope();
    srcSetSignal2.value = await getSrcSet({
      src: props2.src,
      width: props2.width,
      height: props2.height,
      aspectRatio: props2.aspectRatio,
      layout: props2.layout,
      resolutions: resolutions2,
      imageTransformer$: imageTransformer$2
    });
  }, "Image_component_useTask_0QcMuLuR0Hw", [
    imageTransformer$,
    props,
    resolutions,
    srcSetSignal
  ]));
  const imageAttributesWithoutChildren = {
    ...imageAttributes,
    children: void 0
  };
  return /* @__PURE__ */ qwik._jsxS("img", {
    ...imageAttributesWithoutChildren,
    style,
    sizes
  }, {
    decoding: "async",
    width: qwik._fnSignal((p0) => [
      "fullWidth",
      "constrained"
    ].includes(p0.layout) ? void 0 : p0.width, [
      props
    ], '["fullWidth","constrained"].includes(p0.layout)?undefined:p0.width'),
    height: qwik._fnSignal((p0) => [
      "fullWidth",
      "constrained"
    ].includes(p0.layout) ? void 0 : p0.height, [
      props
    ], '["fullWidth","constrained"].includes(p0.layout)?undefined:p0.height'),
    srcSet: qwik._fnSignal((p0) => p0.value, [
      srcSetSignal
    ], "p0.value")
  }, 0, "ET_0");
}, "Image_component_vchO0uJY55k"));

exports.DEFAULT_RESOLUTIONS = DEFAULT_RESOLUTIONS;
exports.Image = Image;
exports.ImageContext = ImageContext;
exports.getBreakpoints = getBreakpoints;
exports.getSizes = getSizes;
exports.getSrcSet = getSrcSet;
exports.getStyles = getStyles;
exports.isValid = isValid;
exports.useImageProvider = useImageProvider;
